%define PKGRELEASE %(echo %{version} | cut -d. -f1,2)

Name:		povray
Version:	3.7.0.10
Summary:	The Persistence of Vision Raytracer
Release:	%mkrel 8
Group:		Sciences/Computer science
# Examples below distribution/ are CC-BY-SA
# The sources are AGPLv3+
License:	AGPLv3+
URL:		https://www.povray.org/
Source:		https://github.com/POV-Ray/povray/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	povray.bash-completion
# Fedora patches:
Patch10:	0001-Fix-encoding.patch
Patch11:	0002-Autotool-massaging.patch
Patch12:	0003-Remove-povuser.patch
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(sdl)
BuildRequires:	pkgconfig(xpm)
BuildRequires:	autoconf
BuildRequires:	automake

%description
The Persistence of Vision Ray tracer creates three-dimensional,
photo-realistic images using a rendering technique called ray tracing.
It reads in a text file containing information describing the objects and
lighting in a scene and generates an image of that scene from the view
point of a camera also described in the text file. Ray tracing is not
a fast process by any means, (the generation of a complex image can
take several hours) but it produces very high quality images
with realistic reflections, shading, perspective, and other effects.
POV-Ray is a free, full-featured ray tracer.

%package scenes
Summary:	POV-Ray example scenes
License:	CC-BY-SA
BuildArch:	noarch

%description scenes
POV-Ray example scenes.

%prep
%setup -q
%autopatch -p1

# Make sure not to be using bundled libs
rm -rf libraries

# Workaround to automake incompatibility
rm -f config/missing

%build
pushd unix
sed -i \
 -e 's,automake --warnings=all,automake -a -f,' \
 prebuild.sh

sed -i \
 -e 's,AM_INIT_AUTOMAKE(\[1.9 dist-bzip2\]),AM_INIT_AUTOMAKE([1.9 dist-bzip2 subdir-objects]),' \
 configure.ac

./prebuild.sh
popd

%configure \
  --disable-silent-rules \
  --disable-optimiz \
  --disable-strip \
  --x-includes=%{_includedir} \
  --x-libraries=%{_libdir} \
  --with-boost-libdir=%{_libdir} \
  --with-x \
  COMPILED_BY="%_vendor"

# Filter out bogus and potentially harmful
# -I%%{_includedir} -L%%{_libdir}
# from Makefiles
find -name Makefile -exec sed -i \
  -e 's,-I%{_includedir}$,,g;s,-I%{_includedir} ,,g;' \
  -e 's,-L%{_libdir}$,,g;s,-L%{_libdir} ,,g' {} \;

# Adjust bogus paths
sed -i \
  -e '/DEFAULT_DIR=/d' \
  -e 's,SYSCONFDIR=\$DEFAULT_DIR/etc,SYSCONFDIR=%{_sysconfdir},' \
  unix/scripts/{allanim,allscene,portfolio}.sh

%make_build

%install
%make_install povdocdir=%{_docdir}/%{name}

# Fixup permissions
chmod +x %{buildroot}%{_datadir}/%{name}-%{PKGRELEASE}/scenes/camera/mesh_camera/bake.sh

install -d -m 755 %{buildroot}%{_sysconfdir}/bash_completion.d
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}

%files
%config(noreplace) %{_sysconfdir}/bash_completion.d/%{name}
%doc %{_docdir}/%{name}
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*
%{_datadir}/%{name}-%{PKGRELEASE}
%exclude %{_datadir}/%{name}-%{PKGRELEASE}/scenes
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/%{PKGRELEASE}
%config(noreplace) %{_sysconfdir}/%{name}/%{PKGRELEASE}/%{name}*

%files scenes
%dir %{_datadir}/%{name}-%{PKGRELEASE}
%{_datadir}/%{name}-%{PKGRELEASE}/scenes


%changelog
* Sat Dec 24 2022 wally <wally> 3.7.0.10-8.mga9
+ Revision: 1926522
- rebuild for boost 1.81.0

* Mon Dec 12 2022 ns80 <ns80> 3.7.0.10-7.mga9
+ Revision: 1921099
- rebuild for new libtiff

* Sun Jul 03 2022 wally <wally> 3.7.0.10-6.mga9
+ Revision: 1867302
- rebuild for boost 1.79.0

* Fri Apr 01 2022 umeabot <umeabot> 3.7.0.10-5.mga9
+ Revision: 1839304
- Mageia 9 Mass Rebuild

* Sat Dec 25 2021 wally <wally> 3.7.0.10-4.mga9
+ Revision: 1763704
- rebuild for openexr 3.1.3

* Sun Dec 19 2021 wally <wally> 3.7.0.10-3.mga9
+ Revision: 1762629
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 3.7.0.10-2.mga9
+ Revision: 1744678
- rebuild for boost 1.77.0

* Mon Aug 09 2021 kekepower <kekepower> 3.7.0.10-1.mga9
+ Revision: 1740777
- Update to version 3.7.0.10

* Fri May 14 2021 wally <wally> 3.7.0.8-10.mga9
+ Revision: 1723009
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 3.7.0.8-9.mga8
+ Revision: 1666807
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 3.7.0.8-8.mga8
+ Revision: 1662049
- rebuild for boost 1.74.0

* Sat Sep 26 2020 tv <tv> 3.7.0.8-7.mga8
+ Revision: 1630184
- rebuild for new libIlmImf

* Sun May 03 2020 wally <wally> 3.7.0.8-6.mga8
+ Revision: 1578102
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 3.7.0.8-5.mga8
+ Revision: 1544887
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 3.7.0.8-4.mga8
+ Revision: 1483421
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Tue Oct 16 2018 wally <wally> 3.7.0.8-3.mga7
+ Revision: 1321084
- rebuild for new boost 1.68.0

* Tue Oct 16 2018 daviddavid <daviddavid> 3.7.0.8-2.mga7
+ Revision: 1320929
- rebuild for new ilmbase and openexr 2.3.0

* Mon Aug 27 2018 kekepower <kekepower> 3.7.0.8-1.mga7
+ Revision: 1255107
- Update to version 3.7.0.8

* Sun May 27 2018 wally <wally> 3.7.0.7-2.mga7
+ Revision: 1232430
- rebuild for openexr 2.2.1

* Sat Jan 13 2018 wally <wally> 3.7.0.7-1.mga7
+ Revision: 1192606
- new version 3.7.0.7
- sync patches with fedora
- drop unneeded linking patch

* Sat Jan 13 2018 wally <wally> 3.7.0-0.20131116git39ce8a2.18.mga7
+ Revision: 1192569
- rebuild for new ilmbase

* Mon Dec 25 2017 wally <wally> 3.7.0-0.20131116git39ce8a2.17.mga7
+ Revision: 1184702
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 3.7.0-0.20131116git39ce8a2.16.mga7
+ Revision: 1178342
- rebuild for boost 1.65

* Sat Sep 23 2017 tv <tv> 3.7.0-0.20131116git39ce8a2.15.mga7
+ Revision: 1158161
- rebuild with latest boost

* Sun Dec 27 2015 daviddavid <daviddavid> 3.7.0-0.20131116git39ce8a2.14.mga6
+ Revision: 916052
- rebuild for new boost 1.60.0

* Sat Sep 26 2015 daviddavid <daviddavid> 3.7.0-0.20131116git39ce8a2.13.mga6
+ Revision: 883887
- rebuild for new boost 1.59.0

* Thu Aug 27 2015 cjw <cjw> 3.7.0-0.20131116git39ce8a2.12.mga6
+ Revision: 870346
- rebuild with gcc 5

* Sun Aug 02 2015 daviddavid <daviddavid> 3.7.0-0.20131116git39ce8a2.11.mga6
+ Revision: 860777
- rebuild for new boost-1.58.0

* Wed Oct 15 2014 umeabot <umeabot> 3.7.0-0.20131116git39ce8a2.10.mga5
+ Revision: 749925
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.7.0-0.20131116git39ce8a2.9.mga5
+ Revision: 687747
- Mageia 5 Mass Rebuild

* Sun Aug 24 2014 luigiwalser <luigiwalser> 3.7.0-0.20131116git39ce8a2.8.mga5
+ Revision: 667000
- rebuild for ilmbase and OpenEXR

* Thu May 01 2014 luigiwalser <luigiwalser> 3.7.0-0.20131116git39ce8a2.7.mga5
+ Revision: 619155
- rebuild for ilmbase

* Tue Apr 15 2014 alexl <alexl> 3.7.0-0.20131116git39ce8a2.6.mga5
+ Revision: 615135
- change level for link patch
- merge with fdr
- update sources
- change license from POV-Ray into AGPLv3+

* Sat Feb 08 2014 barjac <barjac> 3.7.0-0.RC7.5.mga5.nonfree
+ Revision: 586747
- rebuild against boost-1.55

* Thu Oct 31 2013 tmb <tmb> 3.7.0-0.RC7.4.mga4.nonfree
+ Revision: 548464
- Mageia 4 rebuild

* Thu Sep 12 2013 fwang <fwang> 3.7.0-0.RC7.3.mga4.nonfree
+ Revision: 477859
- rebuild for new openexr

* Thu Jul 11 2013 fwang <fwang> 3.7.0-0.RC7.2.mga4.nonfree
+ Revision: 452798
- rebuild for new boost
- drop unused patch

* Mon Jun 03 2013 fwang <fwang> 3.7.0-0.RC7.1.mga4.nonfree
+ Revision: 436171
- 3.7.0 rc7

* Mon Jun 03 2013 fwang <fwang> 3.7.0-0.RC6.6.mga4.nonfree
+ Revision: 436053
- rebuild for new libpng

* Thu Apr 11 2013 barjac <barjac> 3.7.0-0.RC6.5.mga3.nonfree
+ Revision: 409659
- rebuild for boost-1.53
- license corrected
- package removed from core and will be pushed to non-free

* Sun Jan 13 2013 umeabot <umeabot> 3.7.0-0.RC6.4.mga3
+ Revision: 378133
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 3.7.0-0.RC6.3.mga3
+ Revision: 333064
- rebuild for new boost

* Sun Dec 02 2012 fwang <fwang> 3.7.0-0.RC6.2.mga3
+ Revision: 325022
- rebuild for new openexr

* Thu Aug 02 2012 fwang <fwang> 3.7.0-0.RC6.1.mga3
+ Revision: 277922
- more patches
- add archlinux patch to build with latest oost-time
- 3.7 rc6
- specify boost libdir
- fix linkage
- update configure switch
- rebuild for new boost

* Wed May 30 2012 fwang <fwang> 3.7.0-0.RC3.4.mga3
+ Revision: 250111
- rebuild for new boost

* Sun Dec 25 2011 fwang <fwang> 3.7.0-0.RC3.3.mga2
+ Revision: 187439
- rebuild for new libtiff

* Mon Nov 28 2011 fwang <fwang> 3.7.0-0.RC3.2.mga2
+ Revision: 173620
- rebuild for new boost

* Tue Sep 20 2011 fwang <fwang> 3.7.0-0.RC3.1.mga2
+ Revision: 146117
- update file list
- do not create user conf files when packing
- force mt
- add br
- 3.7.0 rc3

* Thu May 05 2011 pterjan <pterjan> 3.6.1-10.mga1
+ Revision: 95072
- Use _vendor for COMPILED_BY
- imported package povray


* Wed Dec 01 2010 Funda Wang <fwang@mandriva.org> 3.6.1-9mdv2011.0
+ Revision: 604381
- bunzip2 patches
- add gentoo patch to detect newer libpng
- build for system new zlib

* Fri Sep 04 2009 Thierry Vignaud <tv@mandriva.org> 3.6.1-8mdv2010.0
+ Revision: 430769
- rebuild

* Fri Aug 01 2008 Thierry Vignaud <tv@mandriva.org> 3.6.1-7mdv2009.0
+ Revision: 259251
- rebuild

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 3.6.1-6mdv2009.0
+ Revision: 247180
- rebuild

* Tue Mar 25 2008 Erwan Velu <erwan@mandriva.org> 3.6.1-4mdv2008.1
+ Revision: 189853
- Fixing bug #31019

* Wed Jan 02 2008 Olivier Blin <oblin@mandriva.com> 3.6.1-3mdv2008.1
+ Revision: 140735
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - fix man pages

* Mon Jun 18 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 3.6.1-3mdv2008.0
+ Revision: 40676
- fix mixture of tabs and spaces
- use macros
- remove obsoletes
- spec file clean


* Fri Feb 09 2007 Erwan Velu <erwan@mandriva.org> 3.6.1-2mdv2007.0
+ Revision: 118487
- Rebuild
- Import povray

* Wed Sep 14 2005 Erwan Velu <erwan@seanodes.com> 3.6.1-1mdk
- 3.6.1

* Sat Sep 10 2005 Olivier Blin <oblin@mandriva.com> 3.1g-20mdk
- fix typo in summary
- Patch19, Patch20: gcc4 fixes

* Thu Mar 24 2005 Erwan Velu <erwan@seanodes.com> 3.1g-19mdk
- Fixing x86_64 build
- Fixing Buildrequires

